@@ -6,25 +6,25 @@ import itertools as it
 from statsmodels.sandbox.stats.multicomp import multipletests
 from statsmodels.stats.multicomp import pairwise_tukeyhsd
 from statsmodels.stats.libqsturng import psturng
-from pandas import DataFrame, Categorical
+from pandas import DataFrame
 
 
-def __convert_to_df(a, val_col=None, group_col=None, val_id=None, group_id=None):
-
+def __convert_to_df(a, val_col: str = 'vals', group_col: str = 'groups',
+                    val_id: int = None, group_id: int = None) -> DataFrame:
     '''Hidden helper method to create a DataFrame with input data for further
     processing.
 
     Parameters
     ----------
     a : array_like or pandas DataFrame object
-        An array, any object exposing the array interface or a pandas DataFrame.
-        Array must be two-dimensional. Second dimension may vary,
-        i.e. groups may have different lengths.
+        An array, any object exposing array interface or a pandas DataFrame.
+        Array must be two-dimensional. Second dimension may vary, i.e. groups
+        may have different lengths.
 
     val_col : str, optional
-        Name of a DataFrame column that contains dependent variable values (test
-        or response variable). Values should have a non-nominal scale. Must be
-        specified if `a` is a pandas DataFrame object.
+        Name of a DataFrame column that contains dependent variable values
+        (test or response variable). Values should have a non-nominal scale.
+        Must be specified if `a` is a pandas DataFrame object.
 
     group_col : str, optional
         Name of a DataFrame column that contains independent variable values
@@ -59,7 +59,6 @@ def __convert_to_df(a, val_col=None, group_col=None, val_id=None, group_id=None)
     -----
     Inferrence algorithm for determining `val_id` and `group_id` args is rather
     simple, so it is better to specify them explicitly to prevent errors.
-
     '''
 
     if not group_col:
@@ -108,7 +107,7 @@ def __convert_to_df(a, val_col=None, group_col=None, val_id=None, group_id=None)
 
 
 def __convert_to_block_df(a, y_col=None, group_col=None, block_col=None, melted=False):
-
+    # TODO: refactor conversion of block data to DataFrame
     if melted and not all([i is not None for i in [block_col, group_col, y_col]]):
         raise ValueError('`block_col`, `group_col`, `y_col` should be explicitly specified if using melted data')
 
@@ -140,15 +139,15 @@ def __convert_to_block_df(a, y_col=None, group_col=None, block_col=None, melted=
 
         else:
             x.rename(columns={group_col: 'groups', block_col: 'blocks', y_col: 'y'}, inplace=True)
-            group_col = 'groups'
-            block_col = 'blocks'
-            y_col = 'y'
 
-    return x, 'y', 'groups', 'blocks'
+    group_col = 'groups'
+    block_col = 'blocks'
+    y_col = 'y'
+
+    return x, y_col, group_col, block_col
 
 
 def posthoc_conover(a, val_col=None, group_col=None, p_adjust=None, sort=True):
-
     '''Post hoc pairwise test for multiple comparisons of mean rank sums
     (Conover's test). May be used after Kruskal-Wallis one-way analysis of
     variance by ranks to do pairwise comparisons [1]_.
@@ -212,15 +211,13 @@ def posthoc_conover(a, val_col=None, group_col=None, p_adjust=None, sort=True):
     def compare_conover(i, j):
         diff = np.abs(x_ranks_avg.loc[i] - x_ranks_avg.loc[j])
         B = (1. / x_lens.loc[i] + 1. / x_lens.loc[j])
-        D = (n - 1. - H_cor) / (n - x_len)
+        D = (n - 1. - h_cor) / (n - x_len)
         t_value = diff / np.sqrt(S2 * B * D)
         p_value = 2. * ss.t.sf(np.abs(t_value), df=n-x_len)
         return p_value
 
     x, _val_col, _group_col = __convert_to_df(a, val_col, group_col)
-
-    if sort:
-        x.sort_values(by=[_group_col, _val_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col, _val_col], ascending=True) if sort else x
 
     n = len(x.index)
     x_groups_unique = x[_group_col].unique()
@@ -237,8 +234,8 @@ def posthoc_conover(a, val_col=None, group_col=None, p_adjust=None, sort=True):
     tie_sum = 0 if not tie_sum else tie_sum
     x_ties = np.min([1., 1. - tie_sum / (n ** 3. - n)])
 
-    H = (12. / (n * (n + 1.))) * np.sum(x_ranks_sum**2 / x_lens) - 3. * (n + 1.)
-    H_cor = H / x_ties
+    h = (12. / (n * (n + 1.))) * np.sum(x_ranks_sum**2 / x_lens) - 3. * (n + 1.)
+    h_cor = h / x_ties
 
     if x_ties == 1:
         S2 = n * (n + 1.) / 12.
@@ -257,14 +254,13 @@ def posthoc_conover(a, val_col=None, group_col=None, p_adjust=None, sort=True):
 
     if p_adjust:
         vs[tri_upper] = multipletests(vs[tri_upper], method=p_adjust)[1]
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
 
     return DataFrame(vs, index=x_groups_unique, columns=x_groups_unique)
 
 
 def posthoc_dunn(a, val_col=None, group_col=None, p_adjust=None, sort=True):
-
     '''Post hoc pairwise test for multiple comparisons of mean rank sums
     (Dunn's test). May be used after Kruskal-Wallis one-way analysis of
     variance by ranks to do pairwise comparisons [1]_, [2]_.
@@ -325,7 +321,6 @@ def posthoc_dunn(a, val_col=None, group_col=None, p_adjust=None, sort=True):
     >>> x = [[1,2,3,5,1], [12,31,54, np.nan], [10,12,6,74,11]]
     >>> sp.posthoc_dunn(x, p_adjust = 'holm')
     '''
-
     def compare_dunn(i, j):
         diff = np.abs(x_ranks_avg.loc[i] - x_ranks_avg.loc[j])
         A = n * (n + 1.) / 12.
@@ -335,8 +330,7 @@ def posthoc_dunn(a, val_col=None, group_col=None, p_adjust=None, sort=True):
         return p_value
 
     x, _val_col, _group_col = __convert_to_df(a, val_col, group_col)
-    if sort:
-        x.sort_values(by=[_group_col, _val_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col, _val_col], ascending=True) if sort else x
 
     n = len(x.index)
     x_groups_unique = x[_group_col].unique()
@@ -365,13 +359,12 @@ def posthoc_dunn(a, val_col=None, group_col=None, p_adjust=None, sort=True):
     if p_adjust:
         vs[tri_upper] = multipletests(vs[tri_upper], method=p_adjust)[1]
 
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=x_groups_unique, columns=x_groups_unique)
 
 
 def posthoc_nemenyi(a, val_col=None, group_col=None,  dist='chi', sort=True):
-
     '''Post hoc pairwise test for multiple comparisons of mean rank sums
     (Nemenyi's test). May be used after Kruskal-Wallis one-way analysis of
     variance by ranks to do pairwise comparisons [1]_.
@@ -435,9 +428,7 @@ def posthoc_nemenyi(a, val_col=None, group_col=None,  dist='chi', sort=True):
         return q
 
     x, _val_col, _group_col = __convert_to_df(a, val_col, group_col)
-
-    if sort:
-        x.sort_values(by=[_group_col, _val_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col, _val_col], ascending=True) if sort else x
 
     n = len(x.index)
     x_groups_unique = x[_group_col].unique()
@@ -472,14 +463,13 @@ def posthoc_nemenyi(a, val_col=None, group_col=None,  dist='chi', sort=True):
 
         vs[tri_upper] = psturng(vs[tri_upper], x_len, np.inf)
 
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
 
     return DataFrame(vs, index=x_groups_unique, columns=x_groups_unique)
 
 
 def posthoc_nemenyi_friedman(a, y_col=None, block_col=None, group_col=None, melted=False, sort=False):
-
     '''Calculate pairwise comparisons using Nemenyi post hoc test for
     unreplicated blocked data. This test is usually conducted post hoc if
     significant results of the Friedman's test are obtained. The statistics
@@ -553,7 +543,6 @@ def posthoc_nemenyi_friedman(a, y_col=None, block_col=None, group_col=None, melt
     >>> # and columns are groups.
     >>> x = np.array([[31,27,24],[31,28,31],[45,29,46],[21,18,48],[42,36,46],[32,17,40]])
     >>> sp.posthoc_nemenyi_friedman(x)
-
     '''
 
     def compare_stats(i, j):
@@ -562,12 +551,7 @@ def posthoc_nemenyi_friedman(a, y_col=None, block_col=None, group_col=None, melt
         return qval
 
     x, _y_col, _group_col, _block_col = __convert_to_block_df(a, y_col, group_col, block_col, melted)
-
-    # if not sort:
-    #    x[group_col] = Categorical(x[group_col], categories=x[group_col].unique(), ordered=True)
-    #    x[block_col] = Categorical(x[block_col], categories=x[block_col].unique(), ordered=True)
-    if sort:
-        x.sort_values(by=[_group_col, _block_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col, _block_col], ascending=True) if sort else x
     x.dropna(inplace=True)
 
     groups = x[_group_col].unique()
@@ -588,13 +572,12 @@ def posthoc_nemenyi_friedman(a, y_col=None, block_col=None, group_col=None, melt
 
     vs *= np.sqrt(2.)
     vs[tri_upper] = psturng(vs[tri_upper], k, np.inf)
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
 
 
 def posthoc_conover_friedman(a, y_col=None, block_col=None, group_col=None, melted=False, sort=False, p_adjust=None):
-
     '''Calculate pairwise comparisons using Conover post hoc test for unreplicated
     blocked data. This test is usually conducted post hoc after
     significant results of the Friedman test. The statistics refer to
@@ -678,7 +661,6 @@ def posthoc_conover_friedman(a, y_col=None, block_col=None, group_col=None, melt
     --------
     >>> x = np.array([[31,27,24],[31,28,31],[45,29,46],[21,18,48],[42,36,46],[32,17,40]])
     >>> sp.posthoc_conover_friedman(x)
-
     '''
 
     def compare_stats(i, j):
@@ -694,12 +676,7 @@ def posthoc_conover_friedman(a, y_col=None, block_col=None, group_col=None, melt
         return pval
 
     x, _y_col, _group_col, _block_col = __convert_to_block_df(a, y_col, group_col, block_col, melted)
-
-    # if not sort:
-    #    x[group_col] = Categorical(x[group_col], categories=x[group_col].unique(), ordered=True)
-    #    x[block_col] = Categorical(x[block_col], categories=x[block_col].unique(), ordered=True)
-    if sort:
-        x.sort_values(by=[_group_col, _block_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col, _block_col], ascending=True) if sort else x
     x.dropna(inplace=True)
 
     groups = x[_group_col].unique()
@@ -732,13 +709,12 @@ def posthoc_conover_friedman(a, y_col=None, block_col=None, group_col=None, melt
         if p_adjust is not None:
             vs[tri_upper] = multipletests(vs[tri_upper], method=p_adjust)[1]
 
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
 
 
 def posthoc_npm_test(a, val_col=None, group_col=None, sort=False, p_adjust=None):
-
     '''Calculate pairwise comparisons using Nashimoto and Wright's all-pairs
     comparison procedure (NPM test) for simply ordered mean ranksums.
 
@@ -804,14 +780,11 @@ def posthoc_npm_test(a, val_col=None, group_col=None, sort=False, p_adjust=None)
     '''
 
     x, _val_col, _group_col = __convert_to_df(a, val_col, group_col)
+    x = x.sort_values(by=[_group_col], ascending=True) if sort else x
 
-    # if not sort:
-    #    x[_group_col] = Categorical(x[_group_col], categories=x[_group_col].unique(), ordered=True)
-    if sort:
-        x.sort_values(by=[_group_col], ascending=True, inplace=True)
     groups = x[_group_col].unique()
     x['ranks'] = x[_val_col].rank()
-    Ri = x.groupby(_group_col)['ranks'].mean()
+    ri = x.groupby(_group_col)['ranks'].mean()
     ni = x.groupby(_group_col)[_val_col].count()
     k = groups.size
     n = x.shape[0]
@@ -819,7 +792,7 @@ def posthoc_npm_test(a, val_col=None, group_col=None, sort=False, p_adjust=None)
     df = np.inf
 
     def compare(m, u):
-        a = [(Ri.loc[groups[u]]-Ri.loc[groups[_mi]])/(sigma/np.sqrt(2)*np.sqrt(1./ni.loc[groups[_mi]] + 1./ni.loc[groups[u]])) for _mi in m]
+        a = [(ri.loc[groups[u]]-ri.loc[groups[_mi]])/(sigma/np.sqrt(2)*np.sqrt(1./ni.loc[groups[_mi]] + 1./ni.loc[groups[u]])) for _mi in m]
         return np.array(a)
 
     stat = np.zeros((k, k))
@@ -837,15 +810,11 @@ def posthoc_npm_test(a, val_col=None, group_col=None, sort=False, p_adjust=None)
     tri_lower = np.tril_indices(p_values.shape[0], -1)
     p_values[tri_lower] = p_values.T[tri_lower]
 
-    # if p_adjust:
-    #    p_values[tri_upper] = multipletests(p_values[tri_upper], method = p_adjust)[1]
-
     np.fill_diagonal(p_values, 1)
     return DataFrame(p_values, index=groups, columns=groups)
 
 
 def posthoc_siegel_friedman(a, y_col=None, block_col=None, group_col=None, melted=False, sort=False, p_adjust=None):
-
     '''Siegel and Castellan's All-Pairs Comparisons Test for Unreplicated Blocked
     Data. See authors' paper for additional information [1]_.
 
@@ -918,7 +887,6 @@ def posthoc_siegel_friedman(a, y_col=None, block_col=None, group_col=None, melte
     --------
     >>> x = np.array([[31,27,24],[31,28,31],[45,29,46],[21,18,48],[42,36,46],[32,17,40]])
     >>> sp.posthoc_siegel_friedman(x)
-
     '''
 
     def compare_stats(i, j):
@@ -927,12 +895,7 @@ def posthoc_siegel_friedman(a, y_col=None, block_col=None, group_col=None, melte
         return zval
 
     x, y_col, group_col, block_col = __convert_to_block_df(a, y_col, group_col, block_col, melted)
-
-    # if not sort:
-    #    x[group_col] = Categorical(x[group_col], categories=x[group_col].unique(), ordered=True)
-    #    x[block_col] = Categorical(x[block_col], categories=x[block_col].unique(), ordered=True)
-    if sort:
-        x.sort_values(by=[group_col, block_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[group_col, block_col], ascending=True) if sort else x
     x.dropna(inplace=True)
 
     groups = x[group_col].unique()
@@ -942,7 +905,7 @@ def posthoc_siegel_friedman(a, y_col=None, block_col=None, group_col=None, melte
     x['mat'] = x.groupby(block_col)[y_col].rank()
     R = x.groupby(group_col)['mat'].mean()
 
-    vs = np.zeros((k, k), dtype=np.float)
+    vs = np.zeros((k, k), dtype=float)
     combs = it.combinations(range(k), 2)
 
     tri_upper = np.triu_indices(vs.shape[0], 1)
@@ -957,13 +920,12 @@ def posthoc_siegel_friedman(a, y_col=None, block_col=None, group_col=None, melte
     if p_adjust:
         vs[tri_upper] = multipletests(vs[tri_upper], method=p_adjust)[1]
 
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
 
 
 def posthoc_miller_friedman(a, y_col=None, block_col=None, group_col=None, melted=False, sort=False):
-
     '''Miller's All-Pairs Comparisons Test for Unreplicated Blocked Data.
     The p-values are computed from the chi-square distribution [1]_, [2]_,
     [3]_.
@@ -1029,7 +991,6 @@ def posthoc_miller_friedman(a, y_col=None, block_col=None, group_col=None, melte
     --------
     >>> x = np.array([[31,27,24],[31,28,31],[45,29,46],[21,18,48],[42,36,46],[32,17,40]])
     >>> sp.posthoc_miller_friedman(x)
-
     '''
 
     def compare_stats(i, j):
@@ -1038,12 +999,7 @@ def posthoc_miller_friedman(a, y_col=None, block_col=None, group_col=None, melte
         return qval
 
     x, y_col, group_col, block_col = __convert_to_block_df(a, y_col, group_col, block_col, melted)
-
-    # if not sort:
-    #    x[group_col] = Categorical(x[group_col], categories=x[group_col].unique(), ordered=True)
-    #    x[block_col] = Categorical(x[block_col], categories=x[block_col].unique(), ordered=True)
-    if sort:
-        x.sort_values(by=[group_col, block_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[group_col, block_col], ascending=True) if sort else x
     x.dropna(inplace=True)
 
     groups = x[group_col].unique()
@@ -1053,10 +1009,9 @@ def posthoc_miller_friedman(a, y_col=None, block_col=None, group_col=None, melte
     x['mat'] = x.groupby(block_col)[y_col].rank()
     R = x.groupby(group_col)['mat'].mean()
 
-    vs = np.zeros((k, k), dtype=np.float)
+    vs = np.zeros((k, k), dtype=float)
     combs = it.combinations(range(k), 2)
 
-    # tri_upper = np.triu_indices(vs.shape[0], 1)
     tri_lower = np.tril_indices(vs.shape[0], -1)
     vs[:, :] = 0
 
@@ -1065,13 +1020,12 @@ def posthoc_miller_friedman(a, y_col=None, block_col=None, group_col=None, melte
     vs = vs ** 2
     vs = ss.chi2.sf(vs, k - 1)
 
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
 
 
 def posthoc_durbin(a, y_col=None, block_col=None, group_col=None, melted=False, sort=False, p_adjust=None):
-
     '''Pairwise post hoc test for multiple comparisons of rank sums according to
     Durbin and Conover for a two-way balanced incomplete block design (BIBD). See
     references for additional information [1]_, [2]_.
@@ -1141,22 +1095,17 @@ def posthoc_durbin(a, y_col=None, block_col=None, group_col=None, melted=False,
     --------
     >>> x = np.array([[31,27,24],[31,28,31],[45,29,46],[21,18,48],[42,36,46],[32,17,40]])
     >>> sp.posthoc_durbin(x)
-
     '''
 
     x, y_col, group_col, block_col = __convert_to_block_df(a, y_col, group_col, block_col, melted)
 
     def compare_stats(i, j):
-        dif = np.abs(Rj[groups[i]] - Rj[groups[j]])
+        dif = np.abs(rj[groups[i]] - rj[groups[j]])
         tval = dif / denom
         pval = 2. * ss.t.sf(np.abs(tval), df=df)
         return pval
 
-    # if not sort:
-    #     x[group_col] = Categorical(x[group_col], categories=x[group_col].unique(), ordered=True)
-    #     x[block_col] = Categorical(x[block_col], categories=x[block_col].unique(), ordered=True)
-    if sort:
-        x.sort_values(by=[block_col, group_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[block_col, group_col], ascending=True) if sort else x
     x.dropna(inplace=True)
 
     groups = x[group_col].unique()
@@ -1165,15 +1114,15 @@ def posthoc_durbin(a, y_col=None, block_col=None, group_col=None, melted=False,
     r = b
     k = t
     x['y_ranked'] = x.groupby(block_col)[y_col].rank()
-    Rj = x.groupby(group_col)['y_ranked'].sum()
+    rj = x.groupby(group_col)['y_ranked'].sum()
     A = (x['y_ranked'] ** 2).sum()
     C = (b * k * (k + 1) ** 2) / 4.
-    D = (Rj ** 2).sum() - r * C
+    D = (rj ** 2).sum() - r * C
     T1 = (t - 1) / (A - C) * D
     denom = np.sqrt(((A - C) * 2 * r) / (b * k - b - t + 1) * (1 - T1 / (b * (k - 1))))
     df = b * k - b - t + 1
 
-    vs = np.zeros((t, t), dtype=np.float)
+    vs = np.zeros((t, t), dtype=float)
     combs = it.combinations(range(t), 2)
 
     tri_upper = np.triu_indices(vs.shape[0], 1)
@@ -1186,13 +1135,12 @@ def posthoc_durbin(a, y_col=None, block_col=None, group_col=None, melted=False,
     if p_adjust:
         vs[tri_upper] = multipletests(vs[tri_upper], method=p_adjust)[1]
 
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
 
 
 def posthoc_anderson(a, val_col=None, group_col=None, midrank=True, sort=False, p_adjust=None):
-
     '''Anderson-Darling Pairwise Test for k-samples. Tests the null hypothesis
     that k-samples are drawn from the same population without having to specify
     the distribution function of that population [1]_.
@@ -1248,17 +1196,14 @@ def posthoc_anderson(a, val_col=None, group_col=None, midrank=True, sort=False,
     --------
     >>> x = np.array([[2.9, 3.0, 2.5, 2.6, 3.2], [3.8, 2.7, 4.0, 2.4], [2.8, 3.4, 3.7, 2.2, 2.0]])
     >>> sp.posthoc_anderson(x)
-
     '''
 
     x, _val_col, _group_col = __convert_to_df(a, val_col, group_col)
-
-    if sort:
-        x.sort_values(by=[_group_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col], ascending=True) if sort else x
 
     groups = x[_group_col].unique()
     k = groups.size
-    vs = np.zeros((k, k), dtype=np.float)
+    vs = np.zeros((k, k), dtype=float)
     combs = it.combinations(range(k), 2)
 
     tri_upper = np.triu_indices(vs.shape[0], 1)
@@ -1271,13 +1216,12 @@ def posthoc_anderson(a, val_col=None, group_col=None, midrank=True, sort=False,
     if p_adjust:
         vs[tri_upper] = multipletests(vs[tri_upper], method=p_adjust)[1]
 
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
 
 
 def posthoc_quade(a, y_col=None, block_col=None, group_col=None, dist='t', melted=False, sort=False, p_adjust=None):
-
     '''Calculate pairwise comparisons using Quade's post hoc test for
     unreplicated blocked data. This test is usually conducted if significant
     results were obtained by the omnibus test [1]_, [2]_, [3]_.
@@ -1374,11 +1318,7 @@ def posthoc_quade(a, y_col=None, block_col=None, group_col=None, dist='t', melte
 
     x, y_col, group_col, block_col = __convert_to_block_df(a, y_col, group_col, block_col, melted)
 
-    # if not sort:
-    #     x[group_col] = Categorical(x[group_col], categories=x[group_col].unique(), ordered=True)
-    #     x[block_col] = Categorical(x[block_col], categories=x[block_col].unique(), ordered=True)
-    if sort:
-        x.sort_values(by=[block_col, group_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[block_col, group_col], ascending=True) if sort else x
     x.dropna(inplace=True)
 
     groups = x[group_col].unique()
@@ -1396,7 +1336,7 @@ def posthoc_quade(a, y_col=None, block_col=None, group_col=None, dist='t', melte
     B = np.sum(S ** 2) / b
     W = x.groupby(group_col)['w'].sum()
 
-    vs = np.zeros((k, k), dtype=np.float)
+    vs = np.zeros((k, k), dtype=float)
     combs = it.combinations(range(k), 2)
 
     tri_upper = np.triu_indices(vs.shape[0], 1)
@@ -1420,13 +1360,12 @@ def posthoc_quade(a, y_col=None, block_col=None, group_col=None, dist='t', melte
     if p_adjust:
         vs[tri_upper] = multipletests(vs[tri_upper], method=p_adjust)[1]
 
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
 
 
 def posthoc_vanwaerden(a, val_col=None, group_col=None, sort=False, p_adjust=None):
-
     '''Van der Waerden's test for pairwise multiple comparisons between group
     levels. See references for additional information [1]_, [2]_.
 
@@ -1492,13 +1431,10 @@ def posthoc_vanwaerden(a, val_col=None, group_col=None, sort=False, p_adjust=Non
     --------
     >>> x = np.array([[10,'a'], [59,'a'], [76,'b'], [10, 'b']])
     >>> sp.posthoc_vanwaerden(x, val_col = 0, group_col = 1)
-
     '''
 
     x, _val_col, _group_col = __convert_to_df(a, val_col, group_col)
-
-    if sort:
-        x.sort_values(by=[_group_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col], ascending=True) if sort else x
 
     groups = x[_group_col].unique()
     n = x[_val_col].size
@@ -1510,10 +1446,9 @@ def posthoc_vanwaerden(a, val_col=None, group_col=None, sort=False, p_adjust=Non
     nj = x.groupby(_group_col)['z_scores'].count()
     s2 = (1. / (n - 1.)) * (x['z_scores'] ** 2.).sum()
     sts = (1. / s2) * np.sum(aj ** 2. / nj)
-    # param = k - 1
     A = aj / nj
 
-    vs = np.zeros((k, k), dtype=np.float)
+    vs = np.zeros((k, k), dtype=float)
     combs = it.combinations(range(k), 2)
 
     tri_upper = np.triu_indices(vs.shape[0], 1)
@@ -1533,13 +1468,12 @@ def posthoc_vanwaerden(a, val_col=None, group_col=None, sort=False, p_adjust=Non
     if p_adjust:
         vs[tri_upper] = multipletests(vs[tri_upper], method=p_adjust)[1]
 
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
 
 
 def posthoc_ttest(a, val_col=None, group_col=None, pool_sd=False, equal_var=True, p_adjust=None, sort=False):
-
     '''Pairwise T test for multiple comparisons of independent groups. May be
     used after a parametric ANOVA to do pairwise comparisons.
 
@@ -1609,18 +1543,15 @@ def posthoc_ttest(a, val_col=None, group_col=None, pool_sd=False, equal_var=True
     array([[-1.        ,  0.04600899,  0.31269089],
            [ 0.04600899, -1.        ,  0.6327077 ],
            [ 0.31269089,  0.6327077 , -1.        ]])
-
     '''
-
     x, _val_col, _group_col = __convert_to_df(a, val_col, group_col)
-    if sort:
-        x.sort_values(by=[_group_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col], ascending=True) if sort else x
 
     groups = x[_group_col].unique()
     k = groups.size
     xg = x.groupby(by=_group_col)[_val_col]
 
-    vs = np.zeros((k, k), dtype=np.float)
+    vs = np.zeros((k, k), dtype=float)
     tri_upper = np.triu_indices(vs.shape[0], 1)
     tri_lower = np.tril_indices(vs.shape[0], -1)
     vs[:, :] = 0
@@ -1649,12 +1580,12 @@ def posthoc_ttest(a, val_col=None, group_col=None, pool_sd=False, equal_var=True
     if p_adjust:
         vs[tri_upper] = multipletests(vs[tri_upper], method=p_adjust)[1]
 
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
 
-def posthoc_tukey_hsd(x, g, alpha=0.05):
 
+def posthoc_tukey_hsd(x, g, alpha=0.05):
     '''Pairwise comparisons with TukeyHSD confidence intervals. This is a
     convenience function to make statsmodels `pairwise_tukeyhsd` method more
     applicable for further use.
@@ -1687,12 +1618,11 @@ def posthoc_tukey_hsd(x, g, alpha=0.05):
     >>> g = [['a'] * 5, ['b'] * 5, ['c'] * 5]
     >>> sp.posthoc_tukey_hsd(np.concatenate(x), np.concatenate(g))
     '''
-
     result = pairwise_tukeyhsd(x, g, alpha=0.05)
-    groups = np.array(result.groupsunique, dtype=np.str)
+    groups = np.array(result.groupsunique, dtype=str)
     groups_len = len(groups)
 
-    vs = np.zeros((groups_len, groups_len), dtype=np.int)
+    vs = np.zeros((groups_len, groups_len), dtype=int)
 
     for a in result.summary()[1:]:
         a0 = str(a[0])
@@ -1704,12 +1634,11 @@ def posthoc_tukey_hsd(x, g, alpha=0.05):
     vsu = np.triu(vs)
     np.fill_diagonal(vsu, 1)
     tri_lower = np.tril_indices(vsu.shape[0], -1)
-    vsu[tri_lower] = vsu.T[tri_lower]
+    vsu[tri_lower] = np.transpose(vsu)[tri_lower]
     return DataFrame(vsu, index=groups, columns=groups)
 
 
 def posthoc_mannwhitney(a, val_col=None, group_col=None, use_continuity=True, alternative='two-sided', p_adjust=None, sort=True):
-
     '''Pairwise comparisons with Mann-Whitney rank test.
 
     Parameters
@@ -1769,13 +1698,10 @@ def posthoc_mannwhitney(a, val_col=None, group_col=None, use_continuity=True, al
     --------
     >>> x = [[1,2,3,4,5], [35,31,75,40,21], [10,6,9,6,1]]
     >>> sp.posthoc_mannwhitney(x, p_adjust = 'holm')
-
     '''
 
     x, _val_col, _group_col = __convert_to_df(a, val_col, group_col)
-
-    if sort:
-        x.sort_values(by=[_group_col, _val_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col, _val_col], ascending=True) if sort else x
 
     groups = x[_group_col].unique()
     x_len = groups.size
@@ -1783,11 +1709,11 @@ def posthoc_mannwhitney(a, val_col=None, group_col=None, use_continuity=True, al
     xg = x.groupby(_group_col)[_val_col]
     tri_upper = np.triu_indices(vs.shape[0], 1)
     tri_lower = np.tril_indices(vs.shape[0], -1)
-    vs[:,:] = 0
+    vs[:, :] = 0
 
     combs = it.combinations(range(x_len), 2)
 
-    for i,j in combs:
+    for i, j in combs:
         vs[i, j] = ss.mannwhitneyu(
             xg.get_group(groups[i]),
             xg.get_group(groups[j]),
@@ -1797,13 +1723,12 @@ def posthoc_mannwhitney(a, val_col=None, group_col=None, use_continuity=True, al
     if p_adjust:
         vs[tri_upper] = multipletests(vs[tri_upper], method=p_adjust)[1]
 
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
 
 
 def posthoc_wilcoxon(a, val_col=None, group_col=None, zero_method='wilcox', correction=False, p_adjust=None, sort=False):
-
     '''Pairwise comparisons with Wilcoxon signed-rank test. It is a non-parametric
     version of the paired T-test for use with non-parametric ANOVA.
 
@@ -1867,13 +1792,10 @@ def posthoc_wilcoxon(a, val_col=None, group_col=None, zero_method='wilcox', corr
     --------
     >>> x = [[1,2,3,4,5], [35,31,75,40,21], [10,6,9,6,1]]
     >>> sp.posthoc_wilcoxon(x)
-
     '''
 
     x, _val_col, _group_col = __convert_to_df(a, val_col, group_col)
-
-    if sort:
-        x.sort_values(by=[_group_col, _val_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col, _val_col], ascending=True) if sort else x
 
     groups = x[_group_col].unique()
     x_len = groups.size
@@ -1885,7 +1807,7 @@ def posthoc_wilcoxon(a, val_col=None, group_col=None, zero_method='wilcox', corr
 
     combs = it.combinations(range(x_len), 2)
 
-    for i,j in combs:
+    for i, j in combs:
         vs[i, j] = ss.wilcoxon(
             xg.get_group(groups[i]),
             xg.get_group(groups[j]),
@@ -1894,13 +1816,12 @@ def posthoc_wilcoxon(a, val_col=None, group_col=None, zero_method='wilcox', corr
 
     if p_adjust:
         vs[tri_upper] = multipletests(vs[tri_upper], method=p_adjust)[1]
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
 
 
 def posthoc_scheffe(a, val_col=None, group_col=None, sort=False, p_adjust=None):
-
     '''Scheffe's all-pairs comparisons test for normally distributed data with equal
     group variances. For all-pairs comparisons in an one-factorial layout with
     normally distributed residuals and equal variances Scheffe's test can be
@@ -1953,12 +1874,10 @@ def posthoc_scheffe(a, val_col=None, group_col=None, sort=False, p_adjust=None):
     >>> x = pd.DataFrame({"a": [1,2,3,5,1], "b": [12,31,54,62,12], "c": [10,12,6,74,11]})
     >>> x = x.melt(var_name='groups', value_name='values')
     >>> sp.posthoc_scheffe(x, val_col='values', group_col='groups')
-
     '''
 
     x, _val_col, _group_col = __convert_to_df(a, val_col, group_col)
-    if sort:
-        x.sort_values(by=[_group_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col], ascending=True) if sort else x
 
     groups = x[_group_col].unique()
     x_grouped = x.groupby(_group_col)[_val_col]
@@ -1974,16 +1893,16 @@ def posthoc_scheffe(a, val_col=None, group_col=None, sort=False, p_adjust=None):
         f_val = dif ** 2. / A
         return f_val
 
-    vs = np.zeros((groups.size, groups.size), dtype=np.float)
+    vs = np.zeros((groups.size, groups.size), dtype=float)
     tri_lower = np.tril_indices(vs.shape[0], -1)
-    vs[:,:] = 0
+    vs[:, :] = 0
 
     combs = it.combinations(range(groups.size), 2)
 
-    for i,j in combs:
+    for i, j in combs:
         vs[i, j] = compare(groups[i], groups[j])
 
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     p_values = ss.f.sf(vs, groups.size - 1., n - groups.size)
 
     np.fill_diagonal(p_values, 1)
@@ -1991,7 +1910,6 @@ def posthoc_scheffe(a, val_col=None, group_col=None, sort=False, p_adjust=None):
 
 
 def posthoc_tamhane(a, val_col=None, group_col=None, welch=True, sort=False):
-
     '''Tamhane's T2 all-pairs comparison test for normally distributed data with
     unequal variances. Tamhane's T2 test can be performed for all-pairs
     comparisons in an one-factorial layout with normally distributed residuals
@@ -2045,21 +1963,16 @@ def posthoc_tamhane(a, val_col=None, group_col=None, welch=True, sort=False):
     >>> x = pd.DataFrame({"a": [1,2,3,5,1], "b": [12,31,54,62,12], "c": [10,12,6,74,11]})
     >>> x = x.melt(var_name='groups', value_name='values')
     >>> sp.posthoc_tamhane(x, val_col='values', group_col='groups')
-
     '''
 
     x, _val_col, _group_col = __convert_to_df(a, val_col, group_col)
-
-    if sort:
-        x.sort_values(by=[_group_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col], ascending=True) if sort else x
 
     groups = x[_group_col].unique()
     x_grouped = x.groupby(_group_col)[_val_col]
     ni = x_grouped.count()
-    #n = ni.sum()
     xi = x_grouped.mean()
     si = x_grouped.var()
-    #sin = 1. / (n - groups.size) * np.sum(si * (ni - 1))
 
     def compare(i, j):
         dif = xi[i] - xi[j]
@@ -2068,7 +1981,7 @@ def posthoc_tamhane(a, val_col=None, group_col=None, welch=True, sort=False):
         if welch:
             df = A ** 2. / (si[i] ** 2. / (ni[i] ** 2. * (ni[i] - 1.)) + si[j] ** 2. / (ni[j] ** 2. * (ni[j] - 1.)))
         else:
-            ## checks according to Tamhane (1979, p. 474)
+            # checks according to Tamhane (1979, p. 474)
             ok1 = (9./10. <= ni[i]/ni[j]) and (ni[i]/ni[j] <= 10./9.)
             ok2 = (9./10. <= (si[i] / ni[i]) / (si[j] / ni[j])) and\
                 ((si[i] / ni[i]) / (si[j] / ni[j]) <= 10./9.)
@@ -2085,26 +1998,26 @@ def posthoc_tamhane(a, val_col=None, group_col=None, welch=True, sort=False):
         p_val = 2. * ss.t.sf(np.abs(t_val), df=df)
         return p_val
 
-    vs = np.zeros((groups.size, groups.size), dtype=np.float)
+    vs = np.zeros((groups.size, groups.size), dtype=float)
     tri_upper = np.triu_indices(vs.shape[0], 1)
     tri_lower = np.tril_indices(vs.shape[0], -1)
-    vs[:,:] = 0
+    vs[:, :] = 0
 
     combs = it.combinations(range(groups.size), 2)
 
-    for i,j in combs:
+    for i, j in combs:
         vs[i, j] = compare(groups[i], groups[j])
 
     vs[tri_upper] = 1. - (1. - vs[tri_upper]) ** groups.size
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
     vs[vs > 1] = 1
 
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
 
 
-def posthoc_tukey(a, val_col = None, group_col = None, sort = False):
-
+def posthoc_tukey(a, val_col: str = None,
+                  group_col: str = None, sort: bool = False) -> DataFrame:
     '''Performs Tukey's all-pairs comparisons test for normally distributed data
     with equal group variances. For all-pairs comparisons in an
     one-factorial layout with normally distributed residuals and equal variances
@@ -2153,13 +2066,10 @@ def posthoc_tukey(a, val_col = None, group_col = None, sort = False):
     >>> x = pd.DataFrame({"a": [1,2,3,5,1], "b": [12,31,54,62,12], "c": [10,12,6,74,11]})
     >>> x = x.melt(var_name='groups', value_name='values')
     >>> sp.posthoc_tukey(x, val_col='values', group_col='groups')
-
     '''
 
     x, _val_col, _group_col = __convert_to_df(a, val_col, group_col)
-
-    if sort:
-        x.sort_values(by=[_group_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col], ascending=True) if sort else x
     groups = x[_group_col].unique()
     x_grouped = x.groupby(_group_col)[_val_col]
 
@@ -2175,25 +2085,24 @@ def posthoc_tukey(a, val_col = None, group_col = None, sort = False):
         q_val = dif / np.sqrt(A)
         return q_val
 
-    vs = np.zeros((groups.size, groups.size), dtype=np.float)
+    vs = np.zeros((groups.size, groups.size), dtype=float)
     tri_upper = np.triu_indices(vs.shape[0], 1)
     tri_lower = np.tril_indices(vs.shape[0], -1)
-    vs[:,:] = 0
+    vs[:, :] = 0
 
     combs = it.combinations(range(groups.size), 2)
 
-    for i,j in combs:
+    for i, j in combs:
         vs[i, j] = compare(groups[i], groups[j])
 
     vs[tri_upper] = psturng(np.abs(vs[tri_upper]), groups.size, n - groups.size)
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
 
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
 
 
 def posthoc_dscf(a, val_col=None, group_col=None, sort=False):
-
     '''Dwass, Steel, Critchlow and Fligner all-pairs comparison test for a
     one-factorial layout with non-normally distributed residuals. As opposed to
     the all-pairs comparison procedures that depend on Kruskal ranks, the DSCF
@@ -2247,13 +2156,10 @@ def posthoc_dscf(a, val_col=None, group_col=None, sort=False):
     >>> x = pd.DataFrame({"a": [1,2,3,5,1], "b": [12,31,54,62,12], "c": [10,12,6,74,11]})
     >>> x = x.melt(var_name='groups', value_name='values')
     >>> sp.posthoc_dscf(x, val_col='values', group_col='groups')
-
     '''
 
     x, _val_col, _group_col = __convert_to_df(a, val_col, group_col)
-
-    if sort:
-        x.sort_values(by=[_group_col], ascending=True, inplace=True)
+    x = x.sort_values(by=[_group_col], ascending=True) if sort else x
     groups = x[_group_col].unique()
     x_grouped = x.groupby(_group_col)[_val_col]
     n = x_grouped.count()
@@ -2289,7 +2195,7 @@ def posthoc_dscf(a, val_col=None, group_col=None, sort=False):
         vs[i, j] = compare(groups[i], groups[j])
 
     vs[tri_upper] = psturng(np.abs(vs[tri_upper]), k, np.inf)
-    vs[tri_lower] = vs.T[tri_lower]
+    vs[tri_lower] = np.transpose(vs)[tri_lower]
 
     np.fill_diagonal(vs, 1)
     return DataFrame(vs, index=groups, columns=groups)
